@@ -3,10 +3,11 @@ Tools module for MBX AI.
 """
 
 from .client import ToolClient
-from .types import Tool, ToolCall
+from .types import Tool, ToolCall, convert_to_strict_schema
 
 __all__ = [
     "ToolClient",
     "Tool",
     "ToolCall",
+    "convert_to_strict_schema",
 ] 
\ No newline at end of file
